<div><table align="center"><tr><td><img src="https://rickkrasinski.github.io/dfcleanser/graphics/pandas.png" style="width: 120px ; height: 120px"></td><td style="margin-left: 200px"><p style="text-align: left" id="mainTitle"><font size="6">Pandas Dataframe Cleanser</font></p><p id="titleComment"><font size="3">A utility to prepare your pandas dataframe for data analytics.</font></p></td><td><img src="https://rickkrasinski.github.io/dfcleanser/graphics/dataCleansing.png" style="width: 120px ; height: 120px"></td></tr></table></div>

# dfcleanser
Pandas Dataframe Cleanser is a Jupyter Notebook extension that lets you perform operations on a pandas dataframe.



## Chapters
Dataframe Cleanser has the following Chapters supporting specific functionality.
1) Data Import 
2) Data Inspection
3) Data Cleansing
4) Data Transform
5) Data Export
6) Data Utilities

## Users Manual
Refer to the dataframe cleanser <a href="https://rickkrasinski.github.io/dfcleanser-help/index.html"  target="_blank">Users Manual</a> to get detailed info on all aspects of the package.

